Crate xkb_data Copy item path Source ConfigItem Contains the name and description of a keyboard layout. KeyboardLayout A keyboard layout, which contains an optional list of variants, a name, and a description. KeyboardLayouts A list of keyboard layouts parsed from X11_BASE_RULES. KeyboardVariant A variant of a keyboard layout. LayoutList A list of keyboard layouts. VariantList A list of possible variants of a keyboard layout. all_keyboard_layouts Fetches a list of keyboard layouts from the system rules files and user config paths,
merging them together. extra_keyboard_layouts Fetches a list of keyboard layouts from the X11_EXTRAS_RULES const or the file defined in the X11_EXTRA_RULES_XML environment variable. get_keyboard_layouts Fetches a list of keyboard layouts from a path. keyboard_layouts Fetches a list of keyboard layouts from the X11_BASE_RULES const or the file defined in the X11_BASE_RULES_XML environment variable. user_keyboard_layouts Fetches user-specific keyboard layouts from XDG config paths.
On Linux, looks for evdev.xml, on other systems looks for base.xml.
Returns all layouts found from these paths: